@@ -21,7 +21,11 @@ Changelog
 0.0.16:fix: update PYPI info
 0.0.17:fix: update PYPI info
 0.0.18:add: add params to interface
+0.0.19:fix: rename file name
+0.0.20:fix: rename api name
+0.0.21:fix: rename api name
+0.0.22:fix: fix core module
 """
 
-__version__ = "0.0.18"
+__version__ = "0.0.22"
 __author__ = "Albert King"
